// Package wrapper ...
//
// Description : wrapper ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 2023-08-09 18:22
package wrapper

import (
	"fmt"
	"time"
)

// OwnTime ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 18:28 2023/8/9
func OwnTime(inputTime time.Time) *Time {
	return &Time{
		inputTime,
		"2006-01-02 15:04:05", // 标准的时间格式
	}
}

// Time 时间类型
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 18:23 2023/8/9
type Time struct {
	time.Time
	standTimeFormat string
}

// GetCurrentFormatTime 获取当前时间的格式化时间(秒)
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 1:34 上午 2021/10/7
func (t *Time) GetCurrentFormatTime(layout ...string) string {
	return time.Now().In(time.Local).Format(t.getTimeFormat(t.standTimeFormat, layout...))
}

// FormatUnixNano 格式化纳秒时间戳
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 11:54 2022/7/14
func (t *Time) FormatUnixNano(layout ...string) string {
	nano := t.UnixNano() % 1e6
	milli := t.UnixNano() / 1e6
	return t.FormatUnixMilli(milli, layout...) + fmt.Sprintf(" %v", nano)
}

// FormatUnixMilli 格式化毫秒时间戳
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 11:55 2022/7/14
func (t *Time) FormatUnixMilli(timestamp int64, layout ...string) string {
	return time.UnixMilli(timestamp).In(time.Local).Format(t.getTimeFormat(t.standTimeFormat, layout...))
}

// FormatUnixSec ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 12:06 2022/7/14
func (t *Time) FormatUnixSec(timestamp int64, layout ...string) string {
	if len(layout) == 0 {
		layout = []string{"2006-01-02 15:04:05"}
	}
	return time.Unix(timestamp, 0).In(time.Local).Format(layout[0])
}

// ParseISO8601Time 解析 2006-01-02T15:04:05+08:00 格式时间 -> 2006-01-02 15:04:05
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 13:48 2022/7/14
func (t *Time) ParseISO8601Time(parseTime string) string {
	var (
		timeLayout = "2006-01-02T15:04:05+08:00"
		formatTime time.Time
		err        error
	)

	if formatTime, err = time.Parse(timeLayout, parseTime); nil != err {
		return ""
	}

	return formatTime.In(time.Local).Format("2006-01-02 15:04:05")
}

// getTimeFormat 获取时间格式
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 18:37 2023/8/9
func (t *Time) getTimeFormat(defaultFormat string, layout ...string) string {
	if len(layout) > 0 && len(layout[0]) > 0 {
		return layout[0]
	}
	return defaultFormat
}
